pub struct Aar { /* private fields */ }Expand description
Accelerated Address Resolver 0.
Implementations
Sourceimpl Aar
impl Aar
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn tasks_start(self) -> Reg<u32, W>
pub const fn tasks_start(self) -> Reg<u32, W>
Start resolving addresses based on IRKs specified in the IRK data structure.
Sourcepub const fn tasks_stop(self) -> Reg<u32, W>
pub const fn tasks_stop(self) -> Reg<u32, W>
Stop resolving addresses.
Sourcepub const fn subscribe_start(self) -> Reg<Subscribe, RW>
pub const fn subscribe_start(self) -> Reg<Subscribe, RW>
Subscribe configuration for task START.
Sourcepub const fn subscribe_stop(self) -> Reg<Subscribe, RW>
pub const fn subscribe_stop(self) -> Reg<Subscribe, RW>
Subscribe configuration for task STOP.
Sourcepub const fn events_end(self) -> Reg<u32, RW>
pub const fn events_end(self) -> Reg<u32, RW>
Address resolution procedure complete or ended due to an error.
Sourcepub const fn events_resolved(self) -> Reg<u32, RW>
pub const fn events_resolved(self) -> Reg<u32, RW>
Address resolved.
Sourcepub const fn events_notresolved(self) -> Reg<u32, RW>
pub const fn events_notresolved(self) -> Reg<u32, RW>
Address not resolved.
Sourcepub const fn events_error(self) -> Reg<u32, RW>
pub const fn events_error(self) -> Reg<u32, RW>
Operation aborted because of a STOP task or due to an error This event does not generate an interrupt.
Sourcepub const fn publish_end(self) -> Reg<Publish, RW>
pub const fn publish_end(self) -> Reg<Publish, RW>
Publish configuration for event END.
Sourcepub const fn publish_resolved(self) -> Reg<Publish, RW>
pub const fn publish_resolved(self) -> Reg<Publish, RW>
Publish configuration for event RESOLVED.
Sourcepub const fn publish_notresolved(self) -> Reg<Publish, RW>
pub const fn publish_notresolved(self) -> Reg<Publish, RW>
Publish configuration for event NOTRESOLVED.
Sourcepub const fn publish_error(self) -> Reg<Publish, RW>
pub const fn publish_error(self) -> Reg<Publish, RW>
Publish configuration for event ERROR.
Sourcepub const fn errorstatus(self) -> Reg<Errorstatus, R>
pub const fn errorstatus(self) -> Reg<Errorstatus, R>
Error status.
Sourcepub const fn maxresolved(self) -> Reg<Maxresolved, RW>
pub const fn maxresolved(self) -> Reg<Maxresolved, RW>
Maximum number of IRKs to resolve.